@@ -6,7 +6,6 @@ from pathlib import Path
 import cognite.airworkflow.constants as const
 from cognite.airworkflow.function_deployer import FunctionDeployer
 from cognite.airworkflow.master_config import get_master_config, get_parallel_deployment, write_dependency_yamls
-from cognite.airworkflow.model.schedule_assets import execute
 from cognite.airworkflow.model_asset_hierarchy import ModelAssetHierarchy
 from cognite.airworkflow.util import cdf, env, functions, github, yaml
 
@@ -64,28 +63,6 @@ def handle_delete_functions():
             functions.delete_function(client, function.external_id)
 
 
-def handle_deploy_infrastructure_schedules():
-    function_name, project = sys.argv[2].split("@")
-    info = const.AUTHENTICATION[project]
-    client = cdf.experimental_client(info.project)
-    execute(client)
-
-
-def handle_call_schedulemanager():
-    _, project_to_config = get_master_config()
-    for project in project_to_config:
-        client = cdf.experimental_client(project)
-        called = 0
-        for schedulemanager_external_id in const.SCHEDULE_MANAGER_EXTERNAL_IDS:
-            function_asset = client.functions.retrieve(external_id=schedulemanager_external_id)
-            if function_asset is not None:
-                client.functions.call(external_id=schedulemanager_external_id, wait=False)
-                called = 1
-                break
-        if called == 0:
-            raise ValueError("No schedule manager has been deployed in air-functions or air-ds-infrastructure!")
-
-
 def handle_check_deployment():
     function_name, project_name = sys.argv[2].split("@")
     client = cdf.experimental_client(project_name)
@@ -120,9 +97,5 @@ if __name__ == "__main__":
         handle_function_deployments()
     elif sys.argv[1] == "delete":
         handle_delete_functions()
-    elif sys.argv[1] == "infraschedules":
-        handle_deploy_infrastructure_schedules()
-    elif sys.argv[1] == "call_schedulemanager":
-        handle_call_schedulemanager()
     elif sys.argv[1] == "check_deployment":
         handle_check_deployment()
