@@ -49,7 +49,7 @@ def await_function_deployment(client: ExperimentalClient, function_name: str, ma
     while time.time() < t_end:
         function = client.functions.retrieve(external_id=function_name)
         if function is not None:
-            print(f"Function status {function.status}")
+            print(f"Function status {function.status} - Function id {function.id}")
             if function.status == "Ready":
                 return True
             if function.status == "Failed":
